@@ -1136,7 +1136,7 @@ def make(server,**setting):
     last_String = 'package Main;\n\n'+addition+javacode
     files.write(last_String)
     files.close()
-    minepy = "python minepy.py"
+    minepy = "minepy"
     if server == True:
         minepy += " -s"
     if port == True:
